summaryrefslogtreecommitdiff
path: root/src/libsystemd-network/network-internal.c
diff options
context:
space:
mode:
authorZbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>2019-06-17 13:38:40 +0200
committerZbigniew Jędrzejewski-Szmek <zbyszek@in.waw.pl>2019-06-17 13:43:18 +0200
commitb889a0ded8ef41e19ea0e64d0afa657e864134ed (patch)
tree9742bdb2424edea3d51827f50cad5b6b3b98f1ec /src/libsystemd-network/network-internal.c
parent2ebe027b448ce729f696e0715456a054ec4a824f (diff)
downloadsystemd-b889a0ded8ef41e19ea0e64d0afa657e864134ed.tar.gz
systemd-b889a0ded8ef41e19ea0e64d0afa657e864134ed.tar.bz2
systemd-b889a0ded8ef41e19ea0e64d0afa657e864134ed.zip
libsystemd-network: rename net_get_name() to net_get_name_persistent()
This reflect its role better. (I didn't use …_persistent_name(), because which name is actually used depends on the policy. So it's better not to make this sound like it returns *the* persistent name.)
Diffstat (limited to 'src/libsystemd-network/network-internal.c')
-rw-r--r--src/libsystemd-network/network-internal.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/libsystemd-network/network-internal.c b/src/libsystemd-network/network-internal.c
index a112b9f70f..1a588f10d3 100644
--- a/src/libsystemd-network/network-internal.c
+++ b/src/libsystemd-network/network-internal.c
@@ -24,7 +24,7 @@
#include "utf8.h"
#include "util.h"
-const char *net_get_name(sd_device *device) {
+const char *net_get_name_persistent(sd_device *device) {
const char *name, *field;
assert(device);
@@ -47,9 +47,9 @@ int net_get_unique_predictable_data(sd_device *device, uint64_t *result) {
assert(device);
- /* net_get_name() will return one of the device names based on stable information about the
- * device. If this is not available, we fall back to using the device name. */
- name = net_get_name(device);
+ /* net_get_name_persistent() will return one of the device names based on stable information about
+ * the device. If this is not available, we fall back to using the actual device name. */
+ name = net_get_name_persistent(device);
if (!name)
(void) sd_device_get_sysname(device, &name);
if (!name)